@@ -16,7 +16,10 @@ __all__ = [
     'FileBatch',
     'Identity',
     'IdentityEvent',
+    'KYCVerification',
+    'LimitedWallet',
     'LoginToken',
+    'Platform',
     'Saving',
     'ServiceProvider',
     'Session',
@@ -25,6 +28,7 @@ __all__ = [
     'User',
     'UserEvent',
     'UserLogin',
+    'Verification',
     'WalletTransaction',
     'Webhook',
     'WhatsappTransfer',
@@ -47,7 +51,10 @@ from .file_batches import FileBatch
 from .files import File
 from .identities import Identity
 from .identity_events import IdentityEvent
+from .kyc_verifications import KYCVerification
+from .limited_wallets import LimitedWallet
 from .login_tokens import LoginToken
+from .platforms import Platform
 from .resources import RESOURCES
 from .savings import Saving
 from .service_providers import ServiceProvider
@@ -58,6 +65,7 @@ from .user_credentials import UserCredential
 from .user_events import UserEvent
 from .user_logins import UserLogin
 from .users import User
+from .verifications import Verification
 from .wallet_transactions import WalletTransaction
 from .webhooks import Webhook
 from .whatsapp_transfers import WhatsappTransfer
@@ -81,6 +89,8 @@ resource_classes = [
     FileBatch,
     Identity,
     IdentityEvent,
+    KYCVerification,
+    LimitedWallet,
     LoginToken,
     Saving,
     Session,
@@ -91,9 +101,11 @@ resource_classes = [
     UserCredential,
     UserEvent,
     UserLogin,
+    Verification,
     WalletTransaction,
     WhatsappTransfer,
     Webhook,
+    Platform,
 ]
 for resource_cls in resource_classes:
     RESOURCES[resource_cls._resource] = resource_cls  # type: ignore
