@@ -12,6 +12,8 @@ def test_user_create(user_request, curp_validation_request):
     user = User.create(**user_request)
     assert user.id is not None
     assert user.level == 0
+    assert not user.clabe
+    assert user.balance == 0
 
 
 @pytest.mark.vcr
@@ -37,6 +39,14 @@ def test_user_update():
     assert all(item in user.to_dict().keys() for item in changes.keys())
 
 
+@pytest.mark.vcr
+def test_user_fetch_balance(user_request, curp_validation_request):
+    user_id = 'USlen-v7UQSqqZTGVe3vQmLQ'
+    user = User.retrieve(user_id)
+    assert user.clabe
+    assert user.balance == 10000
+
+
 @pytest.mark.vcr
 def test_user_identity_retrieve():
     user_id = 'USCM-zlFcNQk6ue4gZ_mTGeQ'
@@ -44,3 +54,19 @@ def test_user_identity_retrieve():
     assert user_id == user.id
     identity = user.identity
     assert identity.id is not None
+
+
+@pytest.mark.vcr
+def test_user_query_by_identity_id():
+    identity_id = 'IDzqdGEBX_SMScteGcRDNtOg'
+    user = User.first(identity_uri=identity_id)
+    assert identity_id in user.identity_uri
+
+
+@pytest.mark.vcr
+def test_user_query_all_identity_id():
+    identity_id = 'IDzqdGEBX_SMScteGcRDNtOg'
+    users = [user for user in User.all(identity_uri=identity_id)]
+    assert len(users) == 2
+    assert users[0].id != users[1].id
+    assert users[0].identity_uri == users[1].identity_uri
